@@ -1,6 +1,7 @@
 import asyncio
 from urllib.parse import urlencode
 from datetime import datetime as dt, timedelta
+import typing
 
 import aiohttp
 import aiohttp_session
@@ -8,6 +9,7 @@ from aiohttp.web import HTTPFound, Request, json_response
 import yarl
 
 from .get_avatar_url import get_avatar_url
+from .oauth_models import OauthMember
 
 
 def get_discord_login_url(request: Request, redirect_uri: str = None) -> str:
@@ -37,7 +39,7 @@ def get_discord_login_url(request: Request, redirect_uri: str = None) -> str:
         parameters['redirect_uri'] = redirect_uri
     if oauth_scopes:
         parameters['scope'] = ' '.join(oauth_scopes)
-    return 'https://discordapp.com/api/oauth2/authorize?' + urlencode(parameters)
+    return 'https://discordapp.com/api/v6/oauth2/authorize?' + urlencode(parameters)
 
 
 async def process_discord_login(request: Request) -> None:
@@ -84,7 +86,7 @@ async def process_discord_login(request: Request) -> None:
     async with aiohttp.ClientSession(loop=request.loop) as session:
 
         # Get auth
-        token_url = "https://discordapp.com/api/oauth2/token"
+        token_url = "https://discordapp.com/api/v6/oauth2/token"
         async with session.post(token_url, data=data, headers=headers) as r:
             token_info = await r.json()
         if token_info.get('error'):
@@ -114,7 +116,7 @@ async def get_user_info_from_session(request: Request, *, refresh: bool = False)
     session_storage = await aiohttp_session.get_session(request)
     if refresh is False:
         return session_storage['user_info']
-    user_url = "https://discordapp.com/api/users/@me"
+    user_url = "https://discordapp.com/api/v6/users/@me"
     headers = {
         'Content-Type': 'application/x-www-form-urlencoded'
     }
@@ -168,7 +170,7 @@ async def get_access_token_from_session(
     async with aiohttp.ClientSession(loop=request.loop) as session:
 
         # Get auth
-        token_url = "https://discordapp.com/api/oauth2/token"
+        token_url = "https://discordapp.com/api/v6/oauth2/token"
         async with session.post(token_url, data=data, headers=headers) as r:
             token_info = await r.json()
         if token_info.get('error'):
@@ -182,7 +184,7 @@ async def get_access_token_from_session(
     return updated_token_info['access_token']
 
 
-async def get_user_guilds_from_session(request: Request):
+async def get_user_guilds_from_session(request: Request, bot_key: str = "bot") -> typing.List[OauthMember]:
     """
     Returns a list of guilds that the user is in based on the request's logged in user.
     """
@@ -197,16 +199,17 @@ async def get_user_guilds_from_session(request: Request):
 
     # Make the request
     async with aiohttp.ClientSession(loop=request.loop) as session:
-        guilds_url = "https://discordapp.com/api/users/@me/guilds"
+        guilds_url = "https://discordapp.com/api/v6/users/@me/guilds"
 
         # Loop until success
         async with session.get(guilds_url, headers=headers) as r:
             guild_info = await r.json()
-            if str(r.status)[0] in ['4', '5']:
+            if not r.ok:
                 return []  # Missing permissions or server error
 
     # Return guild info
-    return guild_info
+    bot = request.app['bots'].get(bot_key)
+    return [OauthMember(bot, i, session_storage['user_info']) for i in guild_info]
 
 
 async def add_user_to_guild_from_session(request: Request, bot_index: str, guild_id: int) -> bool:
@@ -220,7 +223,7 @@ async def add_user_to_guild_from_session(request: Request, bot_index: str, guild
     user_info = session_storage['user_info']
 
     # Get our headers
-    guild_join_url = f"https://discordapp.com/api/guilds/{guild_id}/members/{user_info['id']}"
+    guild_join_url = f"https://discordapp.com/api/v6/guilds/{guild_id}/members/{user_info['id']}"
     headers = {
         'Authorization': f"Bot {request.app['config']['discord_bots'][bot_index]}"
     }
